###
#
# Adds listed deformers to conformed figures.
# Copyright 2008 by Ralf Sesseler
#
###

### options

# set to 1 to hide added deformers
hideDeformer = 0

# list of deformers and actors to deform
deformList = [
	["rthighQuads1", ["rThigh"]],
	["lthighQuads1", ["lThigh"]],
	["rknee1", ["rThigh"]],
	["lknee1", ["lThigh"]],
	["rknee2", ["rShin"]],
	["lknee2", ["lShin"]]
	]

### main

import poser
import string
import os

try: defPose = poser.ScriptLocation() + ".pz2"
except: defPose = poser.AppLocation() + ".pz2"

def createDefPose(figure):
	f = file(defPose, "w")
	f.write("{\n\tversion\n\t{\n\t\tnumber 4\n\t}\n")
	for actor in figure.Actors():
		if actor.IsDeformer():
			a = actor.InternalName()
			n = string.find(a, ':')
			if n != -1: a = a[:n]
			for d in deformList:
				if not a.startswith(d[0]): continue
				f.write("\tmagnetDeformerProp ")
				f.write(a)
				f.write("\n\t{")
				for p in d[1]:
					f.write("\n\t\tdeformTarget ")
					f.write(p)
				f.write("\n\t}\n")
				break
	f.write("}\n")
	f.close()

def addDeform(scene, figure):
	scene.SelectFigure(figure)
	scene.LoadLibraryPose(defPose)
	if hideDeformer:
		for a in figure.Actors():
			for p in a.Parameters():
				if p.TypeCode() == 49:
					p.SetHidden(1)

scene = poser.Scene()
cFigure = scene.CurrentFigure()
if cFigure:
	figure = cFigure.ConformTarget()
	if figure == None:
		createDefPose(cFigure)
		figures = scene.Figures()
		for figure in figures:
			c = figure.ConformTarget()
			if (c != None) and (c.InternalName() == cFigure.InternalName()):
				addDeform(scene, figure)
	else:
		createDefPose(figure)
		addDeform(scene, cFigure)
	os.remove(defPose)
	scene.SelectFigure(cFigure)
	scene.Draw()
